.. _additional-info:

License
=======

MIT License

Copyright (c) 2017-Present Isaak Uchakaev and contributors.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.


Contributors
============

Mimesis is written and maintained by Isaak Uchakaev (Likid Geimfari: `lk-geimfari`_) and various contributors:


Maintainers
~~~~~~~~~~~

-  Likid Geimfari (`lk-geimfari`_)
-  Sobolev Nikita (`sobolevn`_)


Patches and Suggestions
~~~~~~~~~~~~~~~~~~~~~~~

-  Kevin Schellenberg (`wikkiewikkie`_)
-  Casey Weed (`Battleroid`_)
-  Alessandro Martini (`martini97`_)
-  Amin Alaee (`aminalaee`_)
-  Baurzhan Muftakhidinov (`crayxt`_)
-  Benjamin Schwarze (`benjixx`_)
-  Bill DeRusha (`bderusha`_)
-  David Poggi (`drpoggi`_)
-  Eliz Kiliç (`el`_)
-  Flavio Curella (`fcurella`_)
-  FliegendeWurst (`FliegendeWurst`_)
-  JLWT90 (`jlwt90`_)
-  Jack McMorrow (`jackmcmorrow`_)
-  Jakub Wilk (`jwilk`_)
-  Jeremy Costava (`Costava`_)
-  Jin Yang (`redus`_)
-  Json701 (`jasonwaiting-dev`_)
-  Jérôme Christ (`jeromechrist`_)
-  Michael Crilly (`mrcrilly`_)
-  Michael Hand (`mipaaa`_)
-  Paul Walters (`PaulWaltersDev`_)
-  Philipp Offermann (`offermann`_)
-  Sobolev Nikita (`sobolevn`_)
-  Rafael Passos (`auyer`_)
-  Ranwise (`ranwise`_)
-  Sambuddha Basu (`sammyshj`_)
-  Thomas Carroll (`Uncleleech`_)
-  Tsimpitas Dimitris `TsimpDim`_
-  Vladislav Glinsky (`cl0ne`_)
-  Yn-Coder (`yn-coder`_)
-  Dmytro Zelinskyi (`zelds`_)
-  axcel (`axce1`_)
-  Ruslan Valerievich (`Valerievich`_)
-  Simon (`DefaltSimon`_)
-  dy (`duckyou`_)

.. _lk-geimfari: https://github.com/lk-geimfari
.. _sobolevn: https://github.com/sobolevn
.. _duckyou: https://github.com/duckyou
.. _wikkiewikkie: https://github.com/wikkiewikkie
.. _Valerievich: https://github.com/Valerievich
.. _Battleroid: https://github.com/Battleroid
.. _martini97: https://github.com/martini97
.. _aminalaee: https://github.com/aminalaee
.. _crayxt: https://github.com/crayxt
.. _benjixx: https://github.com/benjixx
.. _bderusha: https://github.com/bderusha
.. _drpoggi: https://github.com/drpoggi
.. _el: https://github.com/el
.. _fcurella: https://github.com/fcurella
.. _FliegendeWurst: https://github.com/FliegendeWurst
.. _jlwt90: https://github.com/jlwt90
.. _jackmcmorrow: https://github.com/jackmcmorrow
.. _jwilk: https://github.com/jwilk
.. _Costava: https://github.com/Costava
.. _redus: https://github.com/redus
.. _jasonwaiting-dev: https://github.com/jasonwaiting-dev
.. _jeromechrist: https://github.com/jeromechrist
.. _mrcrilly: https://github.com/mrcrilly
.. _mipaaa: https://github.com/mipaaa
.. _PaulWaltersDev: https://github.com/PaulWaltersDev
.. _offermann: https://github.com/offermann
.. _auyer: https://github.com/auyer
.. _ranwise: https://github.com/ranwise
.. _sammyshj: https://github.com/sammyshj
.. _Uncleleech: https://github.com/Uncleleech
.. _TsimpDim: https://github.com/TsimpDim
.. _cl0ne: https://github.com/cl0ne
.. _yn-coder: https://github.com/yn-coder
.. _zelds: https://github.com/zelds
.. _axce1: https://github.com/axce1
.. _DefaltSimon: https://github.com/DefaltSimon
.. _(ceccoemi): https://github.com/ceccoemi

Disclaimer
==========

The creators of Mimesis do not hold themselves accountable for how you
employ the library's functionalities or the data generated with it.
Mimesis is designed to facilitate testing and with good intentions.
Mimesis should not be used for illicit purposes.
